@@ -29,23 +29,36 @@ from django_jinja import builtins
 JINJA2_FILTERS.update({
     'reverseurl': builtins.filters.reverse,
     'addslashes': builtins.filters.addslashes,
-    'escapejs': builtins.filters.escapejs_filter,
     'capfirst': builtins.filters.capfirst,
+    'escapejs': builtins.filters.escapejs_filter,
+    'fix_ampersands': builtins.filters.fix_ampersands_filter,
     'floatformat': builtins.filters.floatformat,
+    'iriencode': builtins.filters.iriencode,
+    'linenumbers': builtins.filters.linenumbers,
+    'make_list': builtins.filters.make_list,
+    'slugify': builtins.filters.slugify,
+    'stringformat': builtins.filters.stringformat,
+    'title': builtins.filters.title,
     'truncatechars': builtins.filters.truncatechars,
     'truncatewords': builtins.filters.truncatewords,
     'truncatewords_html': builtins.filters.truncatewords_html,
-    'wordwrap': builtins.filters.wordwrap,
-    'title': builtins.filters.title,
-    'slugify': builtins.filters.slugify,
+    'upper': builtins.filters.upper,
     'lower': builtins.filters.lower,
+    'urlencode': builtins.filters.urlencode,
+    'urlize': builtins.filters.urlize,
+    'urlizetrunc': builtins.filters.urlizetrunc,
+    'wordcount': builtins.filters.wordcount,
+    'wordwrap': builtins.filters.wordwrap,
     'ljust': builtins.filters.ljust,
     'rjust': builtins.filters.rjust,
+    'center': builtins.filters.center,
+    'cut': builtins.filters.cut,
     'linebreaksbr': builtins.filters.linebreaksbr,
     'linebreaks': builtins.filters.linebreaks_filter,
     'removetags': builtins.filters.removetags,
     'striptags': builtins.filters.striptags,
     'join': builtins.filters.join,
+    'length': builtins.filters.length,
     'random': builtins.filters.random,
     'add': builtins.filters.add,
     'date': builtins.filters.date,
@@ -58,11 +71,13 @@ JINJA2_FILTERS.update({
     'yesno': builtins.filters.yesno,
     'filesizeformat': builtins.filters.filesizeformat,
     'pprint': builtins.filters.pprint,
+    'pluralize': builtins.filters.pluralize,
     'safe': builtins.filters.safe,
 })
 
 JINJA2_GLOBALS.update({
     'url': builtins.global_context.url,
+    'static': builtins.global_context.static,
 })
 
 
